.. pydataskel documentation master file

SOME DESCRIPTION

Contents
--------

.. toctree::
    :hidden:
    :titlesonly:

    self

.. toctree::
    :maxdepth: 2
    
    api
    examples

* :ref:`genindex`
